@@ -129,6 +129,16 @@ where
     Ok(atomic::AtomicBool::new(val))
 }
 
+pub fn deserialize_arc_atomic_bool<'de, D>(
+    deserializer: D,
+) -> Result<Arc<atomic::AtomicBool>, D::Error>
+where
+    D: Deserializer<'de>,
+{
+    let val = bool::deserialize(deserializer)?;
+    Ok(Arc::new(atomic::AtomicBool::new(val)))
+}
+
 pub fn serialize_duration_as_f64<S>(t: &Duration, s: S) -> Result<S::Ok, S::Error>
 where
     S: Serializer,
